
# Lecture des données
jura  = read.table ("projet/jura.data",header=T)
ntot  = dim(jura)[1]
sel   = rep(F,ntot)

# Selection (eventuelle)
n = ntot
# n = 100


sel[sample(1:ntot)[1:n]] = TRUE
Co    = jura$Co[sel]
x     = jura$x[sel]
y     = jura$y[sel]
lu    = jura$lu
rt    = jura$rt


#
#   I. Exploration des données
#

# Histogramme
par(mfrow=c(1,2))
hist(Co)
boxplot(Co)

# Première visualisation
plot(x,y,xlab="Eastings",ylab="Northings",pch=16,col="blue")
plot(x,y,xlab="Eastings",ylab="Northings",pch=16,col="blue",cex=Co/20)

# Importance de la roche, du land use
boxplot(Co ~ rt,data=jura[sel,],xlab="Rock type",ylab="Co")
boxplot(Co ~ lu,data=jura[sel,],xlab="Land Use",ylab="Co")

# Visualisation avec la roche
plot(x[lu!=1],y[lu!=1],xlab="Eastings",ylab="Northings",pch=16,col="blue",cex=Co[lu!=1]/20)
points(x[lu==1],y[lu==1],xlab="Eastings",ylab="Northings",pch=16,col="red",cex=Co[lu==1]/20)

#
#   II. Analyse Spatiale
#


distsite = disteucl(jura[sel,1:2])
z2       = 0.5*outer(Co,Co,FUN="-")^2

plot(distsite,z2,main="Variogram Cloud",xlab="dist",ylab="vario")
distclas   = floor(distsite/0.2+0.05)*0.2
distvario1 = tapply(distsite,distclas,mean)
vario1     = tapply(z2,distclas,mean,na.rm=T)
nbcouples1 = tapply(z2,distclas,length)
vario1d    = cbind(vario1,distvario1,nbcouples1)

plot(vario1d[,2:1],xlim=c(0,max(distsite/2)),ylim=c(0,var(Co)*1.25),xlab="dist",ylab="vario")

# 1er Essai ajustement
h = seq(0,max(distsite/2),by=0.05)
c0 = 0
c1 = var(Co)
r  = 1.5/3
v = varexp(h,c0,c1,r)  # varsph ou vargauss
points(h,v,type="l",lty=2,lwd=2)

# 2eme Essai ajustement
plot(vario1d[,2:1],xlim=c(0,max(distsite/2)),ylim=c(0,var(Co)*1.25),xlab="dist",ylab="vario")
h = seq(0,max(distsite/2),by=0.05)
c0 = 0
c1 = 13
r  = 1.3/3
v = varexp(h,c0,c1,r)  # varsph ou vargauss
points(h,v,type="l",lty=2,lwd=2)


#
#   III. Prediction spatiale - Krigeage
#

# definition d'une grille sur laquelle sera calcul?e le krigeage
xg   = seq(0,5,0.05)
grid = cbind(rep(xg,length(xg)),sort(rep(xg,length(xg))))

# Matrice de covriance et inversion
a     = covexp(distsite,c0,c1,r)   # covsph ou covgauss
a.inv = solve(a)
k     = sum(a.inv)
u     = a.inv %*% rep(1,n)

# Résolution système de krigeage
kgs  = rep(NA,nrow(grid))
vkgs = rep(NA,nrow(grid))
for (i in 1:nrow(grid)) 
{ 
  b       = covexp(distp(grid[i,1:2],jura[sel,1:2]),c0,c1,r) # covsph ou covgauss
  lambda  = a.inv%*%b
  lambda  = lambda + u*(1-sum(lambda))/k
  kgs[i]  = t(lambda) %*% Co
  vkgs[i] = c0+c1 - t(lambda) %*% b  
}

# Représentation
image(unique(grid[,1]),unique(grid[,1]),matrix(kgs,nrow=length(xg)),main="Krigeage",xlab="Eastings",ylab="Northings",col=terrain.colors(100))
points(jura$x[jura$rt!=1],jura$y[jura$rt!=1],pch=3,cex=Co[jura$rt!=1]/20,col="blue")
points(jura$x[jura$rt==1],jura$y[jura$rt==1],pch=3,cex=Co[jura$rt==1]/20,col="red")
image(unique(grid[,1]),unique(grid[,1]),matrix(vkgs,nrow=length(xg)),main="Variance de K",xlab="Eastings",ylab="Northings",col=terrain.colors(100))
points(jura$x,jura$y,pch=3,cex=Co/20,col="black")

# On peut recommencer avec moins de données

# On peut recommencer avec d'autres fonctions de covariance, ou d'autres paramètres








